@@ -1,3 +1,13 @@
+def floating_point_numbers_retain_decimal_digit(x, decimal_digit=2):
+    dd = decimal_digit
+    a = 10 ** dd * x
+    a = int(a)
+    a /= 10 ** dd
+    return a
+
+def floatdd(x, decimal_digit=2):
+    return floating_point_numbers_retain_decimal_digit(x, decimal_digit)
+
 import platform as p
 import sys
 
